# arpes.plotting.bz\_tool.CoordinateOffsetWidget module

**class
arpes.plotting.bz\_tool.CoordinateOffsetWidget.CoordinateOffsetWidget(parent=None,
root=None, coordinate\_name=None, value=None)**

> Bases: `PyQt5.QtWidgets.QGroupBox`
> 
> **recompute()**
> 
> **value()**
> 
> **value\_changed(event, source)**
